==> openshift-model-console-6.4.1-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleExternalLogLinkSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.console.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ConsoleExternalLogLinkSpecFluentImpl<A extends ConsoleExternalLogLinkSpecFluent<A>> extends BaseFluent<A> implements ConsoleExternalLogLinkSpecFluent<A>{
  public ConsoleExternalLogLinkSpecFluentImpl() {
  }
  public ConsoleExternalLogLinkSpecFluentImpl(ConsoleExternalLogLinkSpec instance) {
    this.withHrefTemplate(instance.getHrefTemplate()); 
    this.withNamespaceFilter(instance.getNamespaceFilter()); 
    this.withText(instance.getText()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String hrefTemplate;
  private String namespaceFilter;
  private String text;
  private Map<String,Object> additionalProperties;
  public String getHrefTemplate() {
    return this.hrefTemplate;
  }
  public A withHrefTemplate(String hrefTemplate) {
    this.hrefTemplate=hrefTemplate; return (A) this;
  }
  public Boolean hasHrefTemplate() {
    return this.hrefTemplate != null;
  }
  public String getNamespaceFilter() {
    return this.namespaceFilter;
  }
  public A withNamespaceFilter(String namespaceFilter) {
    this.namespaceFilter=namespaceFilter; return (A) this;
  }
  public Boolean hasNamespaceFilter() {
    return this.namespaceFilter != null;
  }
  public String getText() {
    return this.text;
  }
  public A withText(String text) {
    this.text=text; return (A) this;
  }
  public Boolean hasText() {
    return this.text != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConsoleExternalLogLinkSpecFluentImpl that = (ConsoleExternalLogLinkSpecFluentImpl) o;
    if (hrefTemplate != null ? !hrefTemplate.equals(that.hrefTemplate) :that.hrefTemplate != null) return false;
    if (namespaceFilter != null ? !namespaceFilter.equals(that.namespaceFilter) :that.namespaceFilter != null) return false;
    if (text != null ? !text.equals(that.text) :that.text != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(hrefTemplate,  namespaceFilter,  text,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (hrefTemplate != null) { sb.append("hrefTemplate:"); sb.append(hrefTemplate + ","); }
    if (namespaceFilter != null) { sb.append("namespaceFilter:"); sb.append(namespaceFilter + ","); }
    if (text != null) { sb.append("text:"); sb.append(text + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-console-6.7.2-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleExternalLogLinkSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.console.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ConsoleExternalLogLinkSpecFluentImpl<A extends ConsoleExternalLogLinkSpecFluent<A>> extends BaseFluent<A> implements ConsoleExternalLogLinkSpecFluent<A>{
  public ConsoleExternalLogLinkSpecFluentImpl() {
  }
  public ConsoleExternalLogLinkSpecFluentImpl(ConsoleExternalLogLinkSpec instance) {
    if (instance != null) {
      this.withHrefTemplate(instance.getHrefTemplate());
      this.withNamespaceFilter(instance.getNamespaceFilter());
      this.withText(instance.getText());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String hrefTemplate;
  private String namespaceFilter;
  private String text;
  private Map<String,Object> additionalProperties;
  public String getHrefTemplate() {
    return this.hrefTemplate;
  }
  public A withHrefTemplate(String hrefTemplate) {
    this.hrefTemplate=hrefTemplate; return (A) this;
  }
  public Boolean hasHrefTemplate() {
    return this.hrefTemplate != null;
  }
  public String getNamespaceFilter() {
    return this.namespaceFilter;
  }
  public A withNamespaceFilter(String namespaceFilter) {
    this.namespaceFilter=namespaceFilter; return (A) this;
  }
  public Boolean hasNamespaceFilter() {
    return this.namespaceFilter != null;
  }
  public String getText() {
    return this.text;
  }
  public A withText(String text) {
    this.text=text; return (A) this;
  }
  public Boolean hasText() {
    return this.text != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConsoleExternalLogLinkSpecFluentImpl that = (ConsoleExternalLogLinkSpecFluentImpl) o;
    if (!java.util.Objects.equals(hrefTemplate, that.hrefTemplate)) return false;

    if (!java.util.Objects.equals(namespaceFilter, that.namespaceFilter)) return false;

    if (!java.util.Objects.equals(text, that.text)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(hrefTemplate,  namespaceFilter,  text,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (hrefTemplate != null) { sb.append("hrefTemplate:"); sb.append(hrefTemplate + ","); }
    if (namespaceFilter != null) { sb.append("namespaceFilter:"); sb.append(namespaceFilter + ","); }
    if (text != null) { sb.append("text:"); sb.append(text + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}
